# SPDX-FileCopyrightText: © 2021 Josef Hahn
# SPDX-License-Identifier: AGPL-3.0-only

import datetime
import time

import lawwenda.mainapp
import lawwendatest


def test_add_share():
    with lawwendatest.tempdir() as cfgdir:
        cfg = lawwenda.Configuration(cfgdir)
        share = cfg.add_share("/foo", name="bar", password="baz")
        assert share.path == "/foo"
        assert share.name == "bar"
        assert share.password_scrypt


def test_get_shares():
    with lawwendatest.tempdir() as cfgdir:
        cfg = lawwenda.Configuration(cfgdir)
        cfg.add_share("/foo", name="bar", password="baz")
        shares = cfg.get_shares()
        assert len(shares) == 1
        assert shares[0].path == "/foo"
        assert shares[0].name == "bar"
        assert shares[0].password_scrypt


def test_get_share_by_name():
    with lawwendatest.tempdir() as cfgdir:
        cfg = lawwenda.Configuration(cfgdir)
        cfg.add_share("/foo", name="bar", password="baz")
        share = cfg.get_share_by_name("bar")
        assert share.path == "/foo"
        assert share.name == "bar"
        assert share.password_scrypt
        assert cfg.get_share_by_name("baaar") is None


def test_remove_share():
    with lawwendatest.tempdir() as cfgdir:
        cfg = lawwenda.Configuration(cfgdir)
        cfg.add_share("/foo", name="bar", password="baz")
        assert cfg.get_share_by_name("bar")
        cfg.remove_share("bar")
        assert cfg.get_share_by_name("bar") is None


def test_share_active_until():
    with lawwendatest.tempdir() as cfgdir:
        cfg = lawwenda.Configuration(cfgdir)
        share = cfg.add_share("/foo", name="bar", password="baz",
                              active_until=datetime.datetime.now()+datetime.timedelta(seconds=9))
        assert cfg.get_share_by_name("bar")
        assert share.is_active
        time.sleep(10)
        assert cfg.get_share_by_name("bar") is None
        assert not share.is_active


def test_share_inactive_after_replaced():
    with lawwendatest.tempdir() as cfgdir:
        cfg = lawwenda.Configuration(cfgdir)
        share = cfg.add_share("/foo", name="bar", password="baz")
        assert share.is_active
        cfg.remove_share("bar")
        assert not share.is_active
        cfg.add_share("/foo", name="bar", password="baz")
        assert not share.is_active


def test_generate_wsgi():
    with lawwendatest.tempdir() as cfgdir:
        cfg = lawwenda.Configuration(cfgdir)
        wsgiscript = cfg.generate_wsgi()
        assert wsgiscript
        locls = {**globals(), **locals()}
        exec(wsgiscript, locls)
        assert isinstance(locls["application"], lawwenda.mainapp.MainApp)


# TODO direct config file changes
