# SPDX-FileCopyrightText: © 2021 Josef Hahn
# SPDX-License-Identifier: AGPL-3.0-only

import urllib.request

import lawwenda.devserver
import lawwendatest


def test_run_get():
    runningbefore = lawwenda.devserver.get_running_dev_servers()
    with lawwendatest.tempdir() as cfgdir:
        newsvr = lawwenda.devserver.run_dev_server(lawwenda.Configuration(cfgdir))
    try:
        assert set(lawwenda.devserver.get_running_dev_servers()) - set(runningbefore) == {newsvr}
    finally:
        newsvr.shutdown()


def test_reachable():
    with lawwendatest.tempdir() as cfgdir:
        with lawwendatest.tempdir() as sharedir:
            cfg = lawwenda.Configuration(cfgdir)
            cfg.add_share(sharedir, name="foo", password=None)
            newsvr = lawwenda.devserver.run_dev_server(cfg)
            try:
                with urllib.request.urlopen(f"{newsvr.url}foo/") as f:
                    assert b"</lawwenda-directoryview>" in f.read()
            finally:
                newsvr.shutdown()


def test_shutdown():
    with lawwendatest.tempdir() as cfgdir:
        newsvr = lawwenda.devserver.run_dev_server(lawwenda.Configuration(cfgdir))
    runningbefore = lawwenda.devserver.get_running_dev_servers()
    newsvr.shutdown()
    # TODO
