# SPDX-FileCopyrightText: © 2021 Josef Hahn
# SPDX-License-Identifier: AGPL-3.0-only

import contextlib
import datetime
import time
import urllib.error
import urllib.request

import pytest

import lawwenda.devserver
import lawwenda.mainapp
import lawwendatest


def test_share_reachable():
    with mainapp_server() as (cfg, svr):
        with pytest.raises(urllib.error.HTTPError):
            with urllib.request.urlopen(f"{svr.url}foo/") as f:
                f.read()
        with lawwendatest.tempdir() as sharedir:
            cfg.add_share(sharedir, name="foo", password=None)
            with urllib.request.urlopen(f"{svr.url}foo/") as f:
                assert b"</lawwenda-directoryview>" in f.read()


def test_share_expire():
    with mainapp_server() as (cfg, svr):
        with lawwendatest.tempdir() as sharedir:
            cfg.add_share(sharedir, name="foo", password=None,
                          active_until=datetime.datetime.now()+datetime.timedelta(seconds=14))
            with urllib.request.urlopen(f"{svr.url}foo/") as f:
                assert b"</lawwenda-directoryview>" in f.read()
            time.sleep(15)
            try:
                with urllib.request.urlopen(f"{svr.url}foo/") as f:
                    f.read()
                assert False
            except urllib.error.HTTPError as ex:
                assert ex.code == 404


@contextlib.contextmanager
def mainapp_server():
    with lawwendatest.tempdir() as cfgdir:
        cfg = lawwenda.Configuration(cfgdir)
        mainapp = lawwenda.mainapp.MainApp(cfgpath=cfgdir)
        svr = lawwenda.devserver._run_dev_server_for_app(mainapp)
        yield cfg, svr
        svr.shutdown()  # TODO encapsulate nicer
