# SPDX-FileCopyrightText: © 2021 Josef Hahn
# SPDX-License-Identifier: AGPL-3.0-only

import lawwenda.fs.factory
import lawwenda.search
import lawwendatest


def test_deeply():
    fs = samplefs()
    assert [n.name for n in lawwenda.search.DeeplySearch("f1").query(fs.rootnode)] == ["f1"]
    assert [n.name for n in lawwenda.search.DeeplySearch("cont3").query(fs.rootnode)] == ["f3"]
    assert [n.name for n in lawwenda.search.DeeplySearch("tag4").query(fs.rootnode)] == ["f4"]
    assert [n.name for n in lawwenda.search.DeeplySearch("comm6").query(fs.rootnode)] == ["f6"]


def test_by_name():
    fs = samplefs()
    assert [n.name for n in lawwenda.search.ByNameSearch("f1").query(fs.rootnode)] == ["f1"]
    assert [n.name for n in lawwenda.search.ByNameSearch("cont3").query(fs.rootnode)] == []
    assert [n.name for n in lawwenda.search.ByNameSearch("tag4").query(fs.rootnode)] == []
    assert [n.name for n in lawwenda.search.ByNameSearch("comm6").query(fs.rootnode)] == []


def test_by_tag():
    fs = samplefs()
    assert [n.name for n in lawwenda.search.ByTagSearch("f1").query(fs.rootnode)] == []
    assert [n.name for n in lawwenda.search.ByTagSearch("cont3").query(fs.rootnode)] == []
    assert [n.name for n in lawwenda.search.ByTagSearch("tag4").query(fs.rootnode)] == ["f4"]
    assert [n.name for n in lawwenda.search.ByTagSearch("comm6").query(fs.rootnode)] == []


def test_by_geo():
    fs = samplefs()
    assert sorted([n.name for n in lawwenda.search.ByGeoSearch(
        "lon=41&lat=41", radius=200_000).query(fs.rootnode)]) == ["f4"]
    assert sorted([n.name for n in lawwenda.search.ByGeoSearch(
        "lon=40&lat=40", radius=2000_000).query(fs.rootnode)]) == ["f3", "f4", "f5"]


def test_create_search():
    assert isinstance(lawwenda.search.create_search("deeply", term="t"), lawwenda.search.DeeplySearch)
    assert isinstance(lawwenda.search.create_search("byname", term="t"), lawwenda.search.ByNameSearch)
    assert isinstance(lawwenda.search.create_search("bytag", term="t"), lawwenda.search.ByTagSearch)
    assert isinstance(lawwenda.search.create_search("bygeo", position="lon=1&lat=1", radius=1),
                      lawwenda.search.ByGeoSearch)


def samplefs():
    fs = lawwendatest.MockFilesystem()
    d1 = fs.rootnode.child_by_name("d1")
    d2 = fs.rootnode.child_by_name("d2")
    d21 = d2.child_by_name("d21")
    for dd in [d1, d2, d21]:
        dd.mkdir()
    # TODO nicer
    f1 = d1.child_by_name("f1")
    f1.write_file(b"cont1")
    f1.set_comment("comm1")
    f1.add_tag("tag1")
    f1.set_geo("lon=10&lat=10")
    f2 = d1.child_by_name("f2")
    f2.write_file(b"cont2")
    f2.set_comment("comm2")
    f2.add_tag("tag2")
    f2.set_geo("lon=20&lat=20")
    f3 = d2.child_by_name("f3")
    f3.write_file(b"cont3")
    f3.set_comment("comm3")
    f3.add_tag("tag3")
    f3.set_geo("lon=30&lat=30")
    f4 = d2.child_by_name("f4")
    f4.write_file(b"cont4")
    f4.set_comment("comm4")
    f4.add_tag("tag4")
    f4.set_geo("lon=40&lat=40")
    f5 = d21.child_by_name("f5")
    f5.write_file(b"cont5")
    f5.set_comment("comm5")
    f5.add_tag("tag5")
    f5.set_geo("lon=50&lat=50")
    f6 = d21.child_by_name("f6")
    f6.write_file(b"cont6")
    f6.set_comment("comm6")
    f6.add_tag("tag6")
    f6.set_geo("lon=60&lat=60")
    return fs
