# SPDX-FileCopyrightText: © 2021 Josef Hahn
# SPDX-License-Identifier: AGPL-3.0-only

import os

import lawwendatest


def test_baseparts():
    with lawwendatest.tempdir_server_share() as tmpsh:
        with lawwendatest.browser() as browser:
            browser.get(tmpsh.share_url)
            assert browser.find_element_by_id("dirview").tag_name == "lawwenda-directoryview"
            assert browser.find_element_by_id("detailspanel").tag_name == "lawwenda-detailspanel"
            assert browser.find_element_by_id("locationbar").tag_name == "lawwenda-locationbar"


def test_dirview():
    with lawwendatest.tempdir_server_share() as tmpsh:
        with open(f"{tmpsh.path}/myfile", "wb") as f:
            f.write(b"f1")
        with lawwendatest.browser() as browser:
            browser.get(tmpsh.share_url)
            assert "myfile" in browser.find_element_by_id("dirview").text


def test_detailspanel():
    with lawwendatest.tempdir_server_share() as tmpsh:
        with open(f"{tmpsh.path}/myfile", "wb") as f:
            f.write(b"f1")
        with lawwendatest.browser() as browser:
            browser.get(tmpsh.share_url)
            dirview = browser.find_element_by_id("dirview")
            detailspanel = browser.find_element_by_id("detailspanel")
            assert "myfile" not in detailspanel.text
            for element in browser.execute_script("return arguments[0].shadowRoot.children", dirview):  # TODO ugly
                myelements = element.find_elements_by_xpath("//*[contains(text(), 'myfile')]")
                if myelements:
                    myelements[0].click()
                    break
            else:
                assert False
            assert "myfile" in detailspanel.text


def test_locationbar():
    with lawwendatest.tempdir_server_share() as tmpsh:
        os.mkdir(f"{tmpsh.path}/mydir")
        with lawwendatest.browser() as browser:
            browser.get(f"{tmpsh.share_url}mydir/")
            locationbar = browser.find_element_by_id("locationbar")
            assert "mydir" in locationbar.text
